@@ -74,7 +74,9 @@ class Scanner(object):
         self.loader = loader
         if self.loader is not None and getattr(self.loader, '_scanner', None) is None:
             self.loader._scanner = self
+        self.reset_scanner()
 
+    def reset_scanner(self):
         # Had we reached the end of the stream?
         self.done = False
 
@@ -131,8 +133,8 @@ class Scanner(object):
     def reader(self):
         # type: () -> Any
         if hasattr(self.loader, 'typ'):
-            self.loader.reader
-        return self.loader._reader
+            self.loader.reader  # type: ignore
+        return self.loader._reader  # type: ignore
 
     # Public methods.
 
